==> lnl-3.1.1.tar.gz: lnl-3.1.1/src/imenu-prot.h <==
/* imenu.c */

#ifdef __cplusplus
extern "C" {
#endif

void	init_var_misc_menu( void );
void	init_misc_menu( void );
char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt );
bool_t	chk_continue_exec_mode( void );
bool_t	set_continue_exec_mode( void );
bool_t	clr_continue_exec_mode( void );
char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_down( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_cancel_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_sel_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_auto_off( menu_t **pp, menu_t **dflt );
char	*cb_menu_show_map_hint( menu_t **pp, menu_t **dflt );
void	show_map_hint( long x, long y );
void	show_map_hint_chr( long x, long y );
void	show_map_hint_obj( long x, long y );
char	*cb_menu_chr_data( menu_t **pp, menu_t **dflt );
char	*menu_sel_mbr_data( void );
long	menu_show_mbr_data( mbr_t *mbr, long *page_n );
long	menu_edit_mbr_data( mbr_t *mbr, long *page_n );
long	menu_mbr_data(
	mbr_t *org_p, long *page_n,
	mbr_data_edit_kind_t edit_kind
);
long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n );
bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p );
char	*menu_sel_mnstr_data( void );
char	*cb_menu_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_divide_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_give_gold( menu_t **pp, menu_t **dflt );
char	*menu_mbr_give_gold( mbr_t *mbr_from );
char	*cb_menu_formation( menu_t **pp, menu_t **dflt );
void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n );
char	*cb_menu_formation_sel_n( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_move_stop( menu_t **pp, menu_t **dflt );
void	move_crsr_abs( long x, long y );
void	move_crsr_rel( long dx, long dy );
char	*cb_menu_crsr_quick_move( menu_t **pp, menu_t **dflt );
void	jump_crsr( long dx, long dy );
char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt );
char	*menu_crsr_move_mbr_n( long mbr_n );
char	*menu_crsr_move_mbr( mbr_t *mbr );
char	*cb_menu_crsr_center( menu_t **pp, menu_t **dflt );
void	scroll_smooth( void );
void	scroll_center( void );
void	chk_scroll( bool_t flg_gui );
void	scroll_half_page( void );
void	move_crsr_mbr_trgt( mbr_t *mbr );
char	*cb_menu_crsr_next_pos_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_door( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_obj( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_square( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_prev_pos( menu_t **pp, menu_t **dflt );
bool_t	next_pos_mbr( long d );
bool_t	next_pos_mnstr( long d );
bool_t	next_pos_mnstr_sub( long *dx, long *dy, long d );
bool_t	next_pos_item( long d );
bool_t	next_pos_obj( long d );
bool_t	next_pos_item_obj( long d, bool_t flg_item );
bool_t	next_pos_item_obj_sub( long *dx, long *dy, long d, bool_t flg_item );
bool_t	next_pos_door( long d );
bool_t	next_pos_square( long d );
bool_t	next_pos_all( long d );
bool_t	prev_pos( void );
char	*cb_menu_back_log( menu_t **pp, menu_t **dflt );
char	*cb_menu_ls_msg( menu_t **pp, menu_t **dflt );
char	*cb_menu_ls_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_cnf( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_fight( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_door( menu_t **pp, menu_t **dflt );
char	*cb_menu_avoid_trap( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_reload( menu_t **pp, menu_t **dflt );
char	*cb_menu_actual_fighting( menu_t **pp, menu_t **dflt );
char	*cb_menu_space_select( menu_t **pp, menu_t **dflt );
char	*cb_menu_reset_file_config( menu_t **pp, menu_t **dflt );
char	*cb_menu_reset_file_town_ptn( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang_ls_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang_ls_priority( menu_t **pp, menu_t **dflt );
char	*cb_menu_window( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_page( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_smooth( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_center( menu_t **pp, menu_t **dflt );
void	set_scroll_page( void );
void	set_scroll_smooth( void );
void	set_scroll_center( void );
char	*cb_menu_redraw_every_turn( menu_t **pp, menu_t **dflt );
char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_measure_clk_tck( menu_t **pp, menu_t **dflt );
char	*cb_menu_color( menu_t **pp, menu_t **dflt );
char	*cb_menu_color_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_fg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg_init( menu_t **pp, menu_t **dflt );
void	menu_color_init( menu_t **pp, menu_t **dflt, int color );
char	*cb_menu_fg( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg( menu_t **pp, menu_t **dflt );
void	set_fg_color( curs_attr_t *attr, int color );
void	set_bg_color( curs_attr_t *attr, int color );
char	*cb_menu_attr_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_attr( menu_t **pp, menu_t **dflt );
void	set_color_attr( curs_attr_t *attr, bool_t flg_on, chtype_t ch );
char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_key_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_clr_key_buf_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_clr_key_buf_every( menu_t **pp, menu_t **dflt );
char	*cb_menu_clr_key_buf_menu( menu_t **pp, menu_t **dflt );
char	*cb_menu_echo_key( menu_t **pp, menu_t **dflt );
char	*cb_menu_set_key( menu_t **pp, menu_t **dflt );
char	*cb_menu_unset_key( menu_t **pp, menu_t **dflt );
char	*cb_menu_macro( menu_t **pp, menu_t **dflt );
char	*cb_menu_macro_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_macro_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_user( menu_t **pp, menu_t **dflt );
void	clr_user_menu( void );
void	add_user_menu( char *name, char *cmd );
char	*get_user_menu_name( long n );
char	*get_user_menu_cmd( long n );
char	*cb_menu_user_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_new( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_arrange_top( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_arrange_bottom( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_remove( menu_t **pp, menu_t **dflt );
void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl );
char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_system( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt );
char	*cb_menu_out_map_file( menu_t **pp, menu_t **dflt );
char	*cb_menu_shell( menu_t **pp, menu_t **dflt );
char	*cb_menu_about_game( menu_t **pp, menu_t **dflt );
char	*cb_menu_exit( menu_t **pp, menu_t **dflt );
void	set_menu_dflt_misc( menu_t *p );
bool_t	*get_ls_flg_srch( void );
menu_t	*get_ls_menu_move_crsr( void );
flg_scroll_t	get_flg_scroll( void );
flg_scroll_t	set_flg_scroll( flg_scroll_t flg );

#ifdef __cplusplus
}
#endif

==> lnl-3.1.6.tar.gz: lnl-3.1.6/src/imenu-prot.h <==
/* imenu.c */

#ifdef __cplusplus
extern "C" {
#endif

void	init_var_misc_menu( void );
void	init_misc_menu( void );
char	*cb_menu_misc( menu_t **pp, menu_t **dflt );
char	*cb_menu_continue_exec( menu_t **pp, menu_t **dflt );
bool_t	chk_continue_exec_mode( void );
bool_t	set_continue_exec_mode( void );
bool_t	clr_continue_exec_mode( void );
char	*cb_menu_stairs( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_up( menu_t **pp, menu_t **dflt );
char	*cb_menu_stairs_down( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_exec_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_cancel_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_sel_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_srch_auto_off( menu_t **pp, menu_t **dflt );
char	*cb_menu_show_map_hint( menu_t **pp, menu_t **dflt );
void	show_map_hint( long x, long y );
void	show_map_hint_chr( long x, long y );
void	show_map_hint_obj( long x, long y );
char	*cb_menu_chr_data( menu_t **pp, menu_t **dflt );
char	*menu_sel_mbr_data( void );
long	menu_show_mbr_data( mbr_t *mbr, long *page_n );
long	menu_edit_mbr_data( mbr_t *mbr, long *page_n );
long	menu_mbr_data(
	mbr_t *org_p, long *page_n,
	mbr_data_edit_kind_t edit_kind
);
long	exec_menu_edit_mbr_data( mbr_t *mbr, data_n_t n );
bool_t	exec_menu_ask_edit_mbr_data( mbr_t *org_p, mbr_t *mbr_p );
char	*menu_sel_mnstr_data( void );
char	*cb_menu_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_collect_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_divide_gold( menu_t **pp, menu_t **dflt );
char	*cb_menu_give_gold( menu_t **pp, menu_t **dflt );
char	*menu_mbr_give_gold( mbr_t *mbr_from );
char	*cb_menu_formation( menu_t **pp, menu_t **dflt );
void	set_menu_formation( menu_t *ls, menu_t **dflt, long mbr_n );
char	*cb_menu_formation_sel_n( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_move( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_move_stop( menu_t **pp, menu_t **dflt );
void	move_crsr_abs( long x, long y );
void	move_crsr_rel( long dx, long dy );
char	*cb_menu_crsr_quick_move( menu_t **pp, menu_t **dflt );
void	jump_crsr( long dx, long dy );
char	*cb_menu_crsr_move_mbr( menu_t **pp, menu_t **dflt );
char	*menu_crsr_move_mbr_n( long mbr_n );
char	*menu_crsr_move_mbr( mbr_t *mbr );
char	*cb_menu_crsr_center( menu_t **pp, menu_t **dflt );
void	scroll_smooth( void );
void	scroll_center( void );
void	chk_scroll( bool_t flg_gui );
void	scroll_half_page( void );
void	move_crsr_mbr_trgt( mbr_t *mbr );
char	*cb_menu_crsr_next_pos_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_item( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_door( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_obj( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_square( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_next_pos_all( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_prev_pos( menu_t **pp, menu_t **dflt );
bool_t	next_pos_mbr( long d );
bool_t	next_pos_mnstr( long d );
bool_t	next_pos_mnstr_sub( long *dx, long *dy, long d );
bool_t	next_pos_item( long d );
bool_t	next_pos_obj( long d );
bool_t	next_pos_item_obj( long d, bool_t flg_item );
bool_t	next_pos_item_obj_sub( long *dx, long *dy, long d, bool_t flg_item );
bool_t	next_pos_door( long d );
bool_t	next_pos_square( long d );
bool_t	next_pos_all( long d );
bool_t	prev_pos( void );
char	*cb_menu_back_log( menu_t **pp, menu_t **dflt );
char	*cb_menu_ls_msg( menu_t **pp, menu_t **dflt );
char	*cb_menu_ls_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_cnf( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg( menu_t **pp, menu_t **dflt );
char	*cb_menu_mbr_flg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_fight( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_door( menu_t **pp, menu_t **dflt );
char	*cb_menu_avoid_trap( menu_t **pp, menu_t **dflt );
char	*cb_menu_auto_reload( menu_t **pp, menu_t **dflt );
char	*cb_menu_actual_fighting( menu_t **pp, menu_t **dflt );
char	*cb_menu_space_select( menu_t **pp, menu_t **dflt );
char	*cb_menu_reset_file_config( menu_t **pp, menu_t **dflt );
char	*cb_menu_reset_file_town_ptn( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang_ls( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang_ls_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_lang_ls_priority( menu_t **pp, menu_t **dflt );
char	*cb_menu_window( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_page( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_smooth( menu_t **pp, menu_t **dflt );
char	*cb_menu_scroll_center( menu_t **pp, menu_t **dflt );
void	set_scroll_page( void );
void	set_scroll_smooth( void );
void	set_scroll_center( void );
char	*cb_menu_redraw_every_turn( menu_t **pp, menu_t **dflt );
char	*cb_menu_mul_msg_line( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mbr( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_mnstr( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_wait( menu_t **pp, menu_t **dflt );
char	*cb_menu_vfx_measure_clk_tck( menu_t **pp, menu_t **dflt );
char	*cb_menu_color( menu_t **pp, menu_t **dflt );
char	*cb_menu_color_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_fg_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg_init( menu_t **pp, menu_t **dflt );
void	menu_color_init( menu_t **pp, menu_t **dflt, int color );
char	*cb_menu_fg( menu_t **pp, menu_t **dflt );
char	*cb_menu_bg( menu_t **pp, menu_t **dflt );
void	set_fg_color( curs_attr_t *attr, int color );
void	set_bg_color( curs_attr_t *attr, int color );
char	*cb_menu_attr_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_attr( menu_t **pp, menu_t **dflt );
void	set_color_attr( curs_attr_t *attr, bool_t flg_on, chtype_t ch );
char	*cb_menu_crsr_ptn( menu_t **pp, menu_t **dflt );
char	*cb_menu_crsr_ptn_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_key_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_clr_key_buf_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_clr_key_buf_every( menu_t **pp, menu_t **dflt );
char	*cb_menu_clr_key_buf_menu( menu_t **pp, menu_t **dflt );
char	*cb_menu_echo_key( menu_t **pp, menu_t **dflt );
char	*cb_menu_set_key( menu_t **pp, menu_t **dflt );
char	*cb_menu_set_key_reg_macro( menu_t **pp, menu_t **dflt );
char	*cb_menu_unset_key( menu_t **pp, menu_t **dflt );
char	*cb_menu_func( menu_t **pp, menu_t **dflt );
char	*cb_menu_func_exec( menu_t **pp, menu_t **dflt );
char	*cb_menu_func_edit( menu_t **pp, menu_t **dflt );
char	*cb_menu_func_set_reg_macro( menu_t **pp, menu_t **dflt );
char	*cb_menu_user( menu_t **pp, menu_t **dflt );
void	clr_user_menu( void );
void	add_user_menu( char *name, char *cmd );
char	*get_user_menu_name( long n );
char	*get_user_menu_cmd( long n );
char	*cb_menu_user_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_new( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_new_reg_macro( menu_t **pp, menu_t **dflt );
char	*menu_user_new_sub(
	menu_t **pp, menu_t **dflt, bool_t flg_reg_macro
);
char	*cb_menu_user_arrange_top( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_arrange_bottom( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_remove( menu_t **pp, menu_t **dflt );
void	set_edit_user_menu( menu_t *ls, menu_call_back_t func, char *ttl );
char	*cb_menu_user_arrange_top_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_arrange_bottom_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_user_remove_sel( menu_t **pp, menu_t **dflt );
char	*cb_menu_system( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_on_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_off_light( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_add_turn( menu_t **pp, menu_t **dflt );
char	*cb_menu_wizard_lev_up( menu_t **pp, menu_t **dflt );
char	*cb_menu_out_map_file( menu_t **pp, menu_t **dflt );
char	*cb_menu_shell( menu_t **pp, menu_t **dflt );
char	*cb_menu_about_game( menu_t **pp, menu_t **dflt );
char	*cb_menu_exit( menu_t **pp, menu_t **dflt );
void	set_menu_dflt_misc( menu_t *p );
bool_t	*get_ls_flg_srch( void );
menu_t	*get_ls_menu_move_crsr( void );
flg_scroll_t	get_flg_scroll( void );
flg_scroll_t	set_flg_scroll( flg_scroll_t flg );

#ifdef __cplusplus
}
#endif
